# Command Line Interface (CLI)

See the [overview of viper's commands](../index.md#commands) for an introduction.

::: mkdocs-click
    :module: viper.cli
    :command: cli
    :prog_name: viper
    :depth: 1
    :style: table
